pub struct ParxBundleWriter { /* private fields */ }Expand description
Writer for PARX bundle files.
Combines multiple Parquet file footers into a single bundle file.
Implementations
Sourceimpl ParxBundleWriter
impl ParxBundleWriter
Sourcepub fn add_entry(
&mut self,
parquet_path: &str,
source_size: u64,
footer_bytes: impl Into<Bytes>,
)
pub fn add_entry( &mut self, parquet_path: &str, source_size: u64, footer_bytes: impl Into<Bytes>, )
Add an entry to the bundle.
Sourcepub fn add_entry_with_page_indexes(
&mut self,
parquet_path: &str,
source_size: u64,
footer_bytes: impl Into<Bytes>,
page_index_bytes: impl Into<Bytes>,
)
pub fn add_entry_with_page_indexes( &mut self, parquet_path: &str, source_size: u64, footer_bytes: impl Into<Bytes>, page_index_bytes: impl Into<Bytes>, )
Add an entry to the bundle with optional page indexes.
Sourcepub fn entry_count(&self) -> usize
pub fn entry_count(&self) -> usize
Get the number of entries in the bundle.